@@ -9,29 +9,11 @@ from sklearn.linear_model import LogisticRegression
 import tensorflow as tf
 from luciferml.supervised.utils.classification_params import *
 
-def build_ann_model(
-    input_units, hidden_layers,
-    input_activation, output_activation,
-    output_units, optimizer, loss, metrics
-):
-    try:
-        classifier = tf.keras.models.Sequential()
-        for i in range(0, hidden_layers):
-            classifier.add(tf.keras.layers.Dense(
-                units=input_units, activation=input_activation))
-        classifier.add(tf.keras.layers.Dense(
-            units=output_units, activation=output_activation))
-        classifier.compile(optimizer=optimizer,
-                        loss=loss, metrics=metrics,)
-        return classifier
-    except Exception as error:
-        print('ANN Build Failed with error :',error, '\n')
-
 
 def classificationPredictor(
         predictor, params, X_train, X_val, y_train, y_val, epochs, hidden_layers,
         input_activation, output_activation, loss,
-        batch_size, metrics, validation_split, optimizer, output_units, input_units,tune_mode
+        batch_size, metrics, validation_split, optimizer, output_units, input_units, tune_mode
 ):
     """
     Takes Predictor string , parameters , Training and Validation set and Returns a classifier for the Choosen Predictor.
@@ -70,7 +52,6 @@ def classificationPredictor(
             elif tune_mode == 3:
                 parameters = parameters_knn_3
 
-
         elif predictor == 'dt':
             print('Training Decision Tree Classifier on Training Set [*]\n')
 
@@ -120,23 +101,40 @@ def classificationPredictor(
                 'learning_rate': [0.3, 0.1, 0.03],
             }
         elif predictor == 'ann':
+            def build_ann_model(input_units):
+                try:
+                    classifier = tf.keras.models.Sequential()
+                    for i in range(0, hidden_layers):
+                        classifier.add(tf.keras.layers.Dense(
+                            units=input_units, activation=input_activation))
+                    classifier.add(tf.keras.layers.Dense(
+                        units=output_units, activation=output_activation))
+                    classifier.compile(optimizer=optimizer,
+                                       loss=loss, metrics=metrics)
+                    return classifier
+
+                except Exception as error:
+                    print('ANN Build Failed with error :', error, '\n')
             print('Training ANN on Training Set [*]\n')
-            classifier = build_ann_model(input_units, hidden_layers,
-                                        input_activation, output_activation,
-                                        output_units, optimizer, loss, metrics)
+            classifier = build_ann_model(input_units)
+
             ann_history = classifier.fit(
                 X_train, y_train, validation_split=validation_split,
                 validation_data=(
                     X_val, y_val), epochs=epochs, batch_size=batch_size
             )
+            classifier_wrap = tf.keras.wrappers.scikit_learn.KerasClassifier(
+                build_fn=build_ann_model, verbose=1, input_units=input_units,
+                epochs=epochs, batch_size=batch_size
+            )
             if tune_mode == 1:
                 parameters = parameters_ann_1
             elif tune_mode == 2:
                 parameters = parameters_ann_2
             elif tune_mode == 3:
                 parameters = parameters_ann_3
-
+        if predictor == 'ann':
+            return (parameters, classifier,classifier_wrap)
         return (parameters, classifier)
-        
     except Exception as error:
         print('Model Build Failed with error :', error, '\n')
